View source: R/brapi_get_commoncropnames.R
| brapi_get_commoncropnames | R Documentation |
Get the Common Crop Names
brapi_get_commoncropnames(con = NULL, page = 0, pageSize = 1000)
con |
list; required: TRUE; BrAPI connection object |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is 'page'= 0).
Default is |
pageSize |
integer; required: FALSE; The size of the pages to be returned.
Default is |
List the common crop names for the crops available in a database server.
This call is required for multi-crop systems where data from multiple crops may be stored in the same database server. A distinct database server is defined by everything in the URL before "/brapi/v2", including host name and base path.
This call is recommended for single crop systems to be compatible with multi-crop clients. For a single crop system the response should contain an array with exactly 1 element.
The common crop name can be used as a search parameter for Programs, Studies, and Germplasm.
data.frame
Maikel Verouden
Other brapi-core:
brapi_get_lists_listDbId(),
brapi_get_lists(),
brapi_get_locations_locationDbId(),
brapi_get_locations(),
brapi_get_people_personDbId(),
brapi_get_people(),
brapi_get_programs_programDbId(),
brapi_get_programs(),
brapi_get_search_lists_searchResultsDbId(),
brapi_get_search_locations_searchResultsDbId(),
brapi_get_search_people_searchResultsDbId(),
brapi_get_search_programs_searchResultsDbId(),
brapi_get_search_studies_searchResultsDbId(),
brapi_get_search_trials_searchResultsDbId(),
brapi_get_seasons_seasonDbId(),
brapi_get_seasons(),
brapi_get_serverinfo(),
brapi_get_studies_studyDbId(),
brapi_get_studies(),
brapi_get_studytypes(),
brapi_get_trials_trialDbId(),
brapi_get_trials(),
brapi_post_lists_listDbId_items(),
brapi_post_lists(),
brapi_post_locations(),
brapi_post_people(),
brapi_post_programs(),
brapi_post_search_lists(),
brapi_post_search_locations(),
brapi_post_search_people(),
brapi_post_search_programs(),
brapi_post_search_studies(),
brapi_post_search_trials(),
brapi_post_seasons(),
brapi_post_studies(),
brapi_post_trials(),
brapi_put_lists_listDbId(),
brapi_put_locations_locationDbId(),
brapi_put_people_personDbId(),
brapi_put_programs_programDbId(),
brapi_put_seasons_seasonDbId(),
brapi_put_studies_studyDbId(),
brapi_put_trials_trialDbId()
## Not run: con <- brapi_db()$testserver brapi_get_commoncropnames(con = con) ## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.