View source: R/brapi_get_events.R
| brapi_get_events | R Documentation |
Get the Events
brapi_get_events( con = NULL, studyDbId = "", observationUnitDbId = "", eventDbId = "", eventType = "", dateRangeStart = "", dateRangeEnd = "", page = 0, pageSize = 1000 )
con |
list; required: TRUE; BrAPI connection object |
studyDbId |
character; required: FALSE; Filter based on an unique study identifier, in which the events occurred. |
observationUnitDbId |
character; required: FALSE; Filter based on an unique observation unit identifier, in which the events occurred. |
eventDbId |
character; required: FALSE; Filter based on an unique event identifier. |
eventType |
character; required: FALSE; Filter based on an event type. |
dateRangeStart |
character; required: FALSE; Start date for filtering based on a date range. Coded in the ISO 8601 standard extended format, where date, time and time zone information needs to be provided (check for example https://www.w3.org/TR/NOTE-datetime ). |
dateRangeEnd |
character; required: FALSE; End date for filtering based on a date range. Coded in the ISO 8601 standard extended format, where date, time and time zone information needs to be provided (check for example https://www.w3.org/TR/NOTE-datetime ). |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is
|
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
Get list of events
data.frame
Maikel Verouden
Other brapi-phenotyping:
brapi_get_images_imageDbId(),
brapi_get_images(),
brapi_get_methods_methodDbId(),
brapi_get_methods(),
brapi_get_observationlevels(),
brapi_get_observations_observationDbId(),
brapi_get_observations_table(),
brapi_get_observations(),
brapi_get_observationunits_observationUnitDbId(),
brapi_get_observationunits_table(),
brapi_get_observationunits(),
brapi_get_ontologies(),
brapi_get_scales_scaleDbId(),
brapi_get_scales(),
brapi_get_search_images_searchResultsDbId(),
brapi_get_search_observations_searchResultsDbId(),
brapi_get_search_observationunits_searchResultsDbId(),
brapi_get_search_variables_searchResultsDbId(),
brapi_get_traits_traitDbId(),
brapi_get_traits(),
brapi_get_variables_observationVariableDbId(),
brapi_get_variables(),
brapi_post_images(),
brapi_post_methods(),
brapi_post_observations(),
brapi_post_observationunits(),
brapi_post_scales(),
brapi_post_search_images(),
brapi_post_search_observations(),
brapi_post_search_observationunits(),
brapi_post_search_variables(),
brapi_post_traits(),
brapi_post_variables(),
brapi_put_images_imageDbId_imagecontent(),
brapi_put_images_imageDbId(),
brapi_put_methods_methodDbId(),
brapi_put_observations_observationDbId(),
brapi_put_observationunits_observationUnitDbId(),
brapi_put_scales_scaleDbId(),
brapi_put_traits_traitDbId(),
brapi_put_variables_observationVariableDbId()
## Not run: con <- brapi_db()$testserver brapi_get_events(con = con) ## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.