brapi_get_observationunits: get /observationunits

View source: R/brapi_get_observationunits.R

brapi_get_observationunitsR Documentation

get /observationunits

Description

Get a filtered set of Observation Units

Usage

brapi_get_observationunits(
  con = NULL,
  observationUnitDbId = "",
  germplasmDbId = "",
  studyDbId = "",
  locationDbId = "",
  trialDbId = "",
  programDbId = "",
  seasonDbId = "",
  observationUnitLevelName = "",
  observationUnitLevelOrder = "",
  observationUnitLevelCode = "",
  includeObservations = NA,
  externalReferenceID = "",
  externalReferenceSource = "",
  page = 0,
  pageSize = 1000
)

Arguments

con

list; required: TRUE; BrAPI connection object

observationUnitDbId

character; required: FALSE; The unique observation unit identifier to filter on.

germplasmDbId

character; required: FALSE; The unique germplasm (accession) identifier to filter on.

studyDbId

character; required: FALSE; The unique study identifier to filter on.

locationDbId

character; required: FALSE; The unique location identifier, where these observations were collected, to filter on.

trialDbId

character; required: FALSE; The unique trial identifier to filter on.

programDbId

character; required: FALSE; The unique program identifier to filter on.

seasonDbId

character; required: FALSE; The year or Phenotyping campaign of a multi-annual study (trees, grape, $...$) to filter on.

observationUnitLevelName

character; required: FALSE; The observation unit level name. Returns only the observation unit of the specified Level. References ObservationUnit->observationUnitPosition ->observationLevel->levelName

observationUnitLevelOrder

character; required: FALSE; The observation unit level order number. Returns only the observation unit of the specified level. References ObservationUnit-&glt;observationUnitPosition ->observationLevel->levelOrder

observationUnitLevelCode

character; required: FALSE; The observation unit level code. This parameter should be used together with observationUnitLevelName or observationUnitLevelOrder. References ObservationUnit->observationUnitPosition->observationLevel ->levelCode

includeObservations

logical; required: FALSE; Use this parameter to include a list of observations embedded in each ObservationUnit object. CAUTION - Use this parameter at your own risk. It may return large, unpaginated lists of observation data. Only set this value to TRUE if you are sure you need to.

externalReferenceID

character; required: FALSE; An external reference ID. Could be a simple string or a URI. (use with externalReferenceSource parameter)

externalReferenceSource

character; required: FALSE; An identifier for the source system or database of an external reference (use with externalReferenceID parameter)

page

integer; required: FALSE; Used to request a specific page of data to be returned. The page indexing starts at 0 (the first page is page = 0). Default is 0.

pageSize

integer; required: FALSE; The size of the pages to be returned. Default is 1000.

Details

Get a filtered set of Observation Units

Value

data.frame

Author(s)

Maikel Verouden

References

BrAPI SwaggerHub

See Also

Other brapi-phenotyping: brapi_get_events(), brapi_get_images_imageDbId(), brapi_get_images(), brapi_get_methods_methodDbId(), brapi_get_methods(), brapi_get_observationlevels(), brapi_get_observations_observationDbId(), brapi_get_observations_table(), brapi_get_observations(), brapi_get_observationunits_observationUnitDbId(), brapi_get_observationunits_table(), brapi_get_ontologies(), brapi_get_scales_scaleDbId(), brapi_get_scales(), brapi_get_search_images_searchResultsDbId(), brapi_get_search_observations_searchResultsDbId(), brapi_get_search_observationunits_searchResultsDbId(), brapi_get_search_variables_searchResultsDbId(), brapi_get_traits_traitDbId(), brapi_get_traits(), brapi_get_variables_observationVariableDbId(), brapi_get_variables(), brapi_post_images(), brapi_post_methods(), brapi_post_observations(), brapi_post_observationunits(), brapi_post_scales(), brapi_post_search_images(), brapi_post_search_observations(), brapi_post_search_observationunits(), brapi_post_search_variables(), brapi_post_traits(), brapi_post_variables(), brapi_put_images_imageDbId_imagecontent(), brapi_put_images_imageDbId(), brapi_put_methods_methodDbId(), brapi_put_observations_observationDbId(), brapi_put_observationunits_observationUnitDbId(), brapi_put_scales_scaleDbId(), brapi_put_traits_traitDbId(), brapi_put_variables_observationVariableDbId()

Other Observation Units: brapi_get_observationlevels(), brapi_get_observationunits_observationUnitDbId(), brapi_get_observationunits_table(), brapi_get_search_observationunits_searchResultsDbId(), brapi_post_observationunits(), brapi_post_search_observationunits(), brapi_put_observationunits_observationUnitDbId()

Examples

## Not run: 
con <- brapi_db()$testserver
brapi_get_observationunits(con = con)

## End(Not run)


mverouden/brapir-v2 documentation built on April 22, 2022, 9:24 a.m.