View source: R/brapi_get_search_attributes_searchResultsDbId.R
| brapi_get_search_attributes_searchResultsDbId | R Documentation |
Get the results of a Germplasm Attributes search request
brapi_get_search_attributes_searchResultsDbId( con = NULL, searchResultsDbId = "", page = 0, pageSize = 1000 )
con |
list; required: TRUE; BrAPI connection object |
searchResultsDbId |
character; required: TRUE; Unique identifier which references the search results |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is
|
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
Get the results of a Germplasm Attributes search request.
data.frame
Maikel Verouden
Other brapi-germplasm:
brapi_get_attributes(),
brapi_get_attributevalues(),
brapi_get_germplasm(),
brapi_get_search_attributevalues_searchResultsDbId(),
brapi_get_search_germplasm_searchResultsDbId(),
brapi_post_search_attributes(),
brapi_post_search_attributevalues(),
brapi_post_search_germplasm()
Other Germplasm Attributes:
brapi_get_attributes(),
brapi_post_search_attributes()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
# Saved or Asynchronous Search Response Example
out <-
brapi_post_search_attributes(
con = con,
attributeDbIds = c("attribute1",
"attribute2"),
attributeNames = "Rht-B2b",
externalReferenceIDs = "https://brapi.org/specification",
externalReferenceSources = "BrAPI Doc",
traitClasses = "Numeric",
page = 0,
pageSize = 1000)
searchResultsDbId <- out$searchResultsDbId
brapi_get_search_attributes_searchResultsDbId(
con = con,
searchResultsDbId = searchResultsDbId)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.