View source: R/brapi_get_search_variables_searchResultsDbId.R
| brapi_get_search_variables_searchResultsDbId | R Documentation |
Get the results of a Observation variables search request
brapi_get_search_variables_searchResultsDbId( con = NULL, searchResultsDbId = "", page = 0, pageSize = 1000 )
con |
list; required: TRUE; BrAPI connection object |
searchResultsDbId |
character; required: TRUE; Unique database identifier which references the search results |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is
|
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
Returns the result of the advanced searching for the observation
variables resource, submitted by the corresponding
Get the results of a Observation variables search request
submitted with the brapi_post_search_variables() function.
data.frame
Maikel Verouden
Other brapi-phenotyping:
brapi_get_events(),
brapi_get_images_imageDbId(),
brapi_get_images(),
brapi_get_methods_methodDbId(),
brapi_get_methods(),
brapi_get_observationlevels(),
brapi_get_observations_observationDbId(),
brapi_get_observations_table(),
brapi_get_observations(),
brapi_get_observationunits_observationUnitDbId(),
brapi_get_observationunits_table(),
brapi_get_observationunits(),
brapi_get_ontologies(),
brapi_get_scales_scaleDbId(),
brapi_get_scales(),
brapi_get_search_images_searchResultsDbId(),
brapi_get_search_observations_searchResultsDbId(),
brapi_get_search_observationunits_searchResultsDbId(),
brapi_get_traits_traitDbId(),
brapi_get_traits(),
brapi_get_variables_observationVariableDbId(),
brapi_get_variables(),
brapi_post_images(),
brapi_post_methods(),
brapi_post_observations(),
brapi_post_observationunits(),
brapi_post_scales(),
brapi_post_search_images(),
brapi_post_search_observations(),
brapi_post_search_observationunits(),
brapi_post_search_variables(),
brapi_post_traits(),
brapi_post_variables(),
brapi_put_images_imageDbId_imagecontent(),
brapi_put_images_imageDbId(),
brapi_put_methods_methodDbId(),
brapi_put_observations_observationDbId(),
brapi_put_observationunits_observationUnitDbId(),
brapi_put_scales_scaleDbId(),
brapi_put_traits_traitDbId(),
brapi_put_variables_observationVariableDbId()
Other Observation Variables:
brapi_get_variables_observationVariableDbId(),
brapi_get_variables(),
brapi_post_search_variables(),
brapi_post_variables(),
brapi_put_variables_observationVariableDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
# Saved or Asynchronous Search Response Example
out <- brapi_post_search_variables(
con = con,
dataTypes = c("Numerical", "Text"),
externalReferenceIDs = "https://brapi.org/specification",
externalReferenceSources = "BrAPI Doc",
ontologyDbIds = "ontology_variable1",
page = 0,
pageSize = 1000)
searchResultsDbId <- out$searchResultsDbId
brapi_get_search_variables_searchResultsDbId(
con = con,
searchResultsDbId = searchResultsDbId)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.