View source: R/brapi_get_studies_studyDbId.R
| brapi_get_studies_studyDbId | R Documentation |
Get the details for a specific Study
brapi_get_studies_studyDbId(con = NULL, studyDbId = "")
con |
list; required: TRUE; BrAPI connection object |
studyDbId |
character; required: TRUE; Identifier of the study. Usually a number, could be alphanumeric. |
Retrieve the information of the study required for field data collection
An additionalInfo field was added to provide a controlled vocabulary for less common data fields.
data.frame
Maikel Verouden
Other brapi-core:
brapi_get_commoncropnames(),
brapi_get_lists_listDbId(),
brapi_get_lists(),
brapi_get_locations_locationDbId(),
brapi_get_locations(),
brapi_get_people_personDbId(),
brapi_get_people(),
brapi_get_programs_programDbId(),
brapi_get_programs(),
brapi_get_search_lists_searchResultsDbId(),
brapi_get_search_locations_searchResultsDbId(),
brapi_get_search_people_searchResultsDbId(),
brapi_get_search_programs_searchResultsDbId(),
brapi_get_search_studies_searchResultsDbId(),
brapi_get_search_trials_searchResultsDbId(),
brapi_get_seasons_seasonDbId(),
brapi_get_seasons(),
brapi_get_serverinfo(),
brapi_get_studies(),
brapi_get_studytypes(),
brapi_get_trials_trialDbId(),
brapi_get_trials(),
brapi_post_lists_listDbId_items(),
brapi_post_lists(),
brapi_post_locations(),
brapi_post_people(),
brapi_post_programs(),
brapi_post_search_lists(),
brapi_post_search_locations(),
brapi_post_search_people(),
brapi_post_search_programs(),
brapi_post_search_studies(),
brapi_post_search_trials(),
brapi_post_seasons(),
brapi_post_studies(),
brapi_post_trials(),
brapi_put_lists_listDbId(),
brapi_put_locations_locationDbId(),
brapi_put_people_personDbId(),
brapi_put_programs_programDbId(),
brapi_put_seasons_seasonDbId(),
brapi_put_studies_studyDbId(),
brapi_put_trials_trialDbId()
Other Studies:
brapi_get_search_studies_searchResultsDbId(),
brapi_get_studies(),
brapi_get_studytypes(),
brapi_post_search_studies(),
brapi_post_studies(),
brapi_put_studies_studyDbId()
## Not run:
con <- brapi_db()$testserver
brapi_get_studies_studyDbId(con = con,
studyDbId = "study1")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.