View source: R/brapi_get_vendor_orders.R
| brapi_get_vendor_orders | R Documentation |
List current available orders
brapi_get_vendor_orders( con = NULL, orderId = "", submissionId = "", page = 0, pageSize = 1000 )
con |
list; required: TRUE; BrAPI connection object |
orderId |
character; required: FALSE; The order identifier returned by the
vendor, when the order was successfully submitted with POST
/vendor/orders as implemented in the |
submissionId |
character; required: FALSE; The submission identifier returned
by the vendor, when a set of plates was successfully submitted with
POST /vendor/orders as implemented in the |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is
|
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
List current available orders.
data.frame
Maikel Verouden
Other brapi-genotyping:
brapi_get_callsets_callSetDbId_calls(),
brapi_get_callsets_callSetDbId(),
brapi_get_callsets(),
brapi_get_calls(),
brapi_get_maps_mapDbId_linkagegroups(),
brapi_get_maps_mapDbId(),
brapi_get_maps(),
brapi_get_markerpositions(),
brapi_get_references_referenceDbId_bases(),
brapi_get_references_referenceDbId(),
brapi_get_referencesets_referenceSetDbId(),
brapi_get_referencesets(),
brapi_get_references(),
brapi_get_samples_sampleDbId(),
brapi_get_samples(),
brapi_get_search_calls_searchResultsDbId(),
brapi_get_search_callsets_searchResultsDbId(),
brapi_get_search_markerpositions_searchResultsDbId(),
brapi_get_search_references_searchResultsDbId(),
brapi_get_search_referencesets_searchResultsDbId(),
brapi_get_search_samples_searchResultsDbId(),
brapi_get_search_variants_searchResultsDbId(),
brapi_get_search_variantsets_searchResultsDbId(),
brapi_get_variants_variantDbId_calls(),
brapi_get_variants_variantDbId(),
brapi_get_variantsets_variantSetDbId_callsets(),
brapi_get_variantsets_variantSetDbId_calls(),
brapi_get_variantsets_variantSetDbId_variants(),
brapi_get_variantsets_variantSetDbId(),
brapi_get_variantsets(),
brapi_get_variants(),
brapi_get_vendor_orders_orderId_plates(),
brapi_get_vendor_orders_orderId_results(),
brapi_get_vendor_orders_orderId_status(),
brapi_get_vendor_specifications(),
brapi_post_samples(),
brapi_post_search_callsets(),
brapi_post_search_calls(),
brapi_post_search_markerpositions(),
brapi_post_search_referencesets(),
brapi_post_search_references(),
brapi_post_search_samples(),
brapi_post_search_variantsets(),
brapi_post_search_variants(),
brapi_post_variantsets_extract(),
brapi_put_samples_sampleDbId()
Other Vendor:
brapi_get_vendor_orders_orderId_plates(),
brapi_get_vendor_orders_orderId_results(),
brapi_get_vendor_orders_orderId_status(),
brapi_get_vendor_specifications()
## Not run: con <- brapi_db()$testserver brapi_get_vendor_orders(con = con) ## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.