View source: R/brapi_post_methods.R
| brapi_post_methods | R Documentation |
Add new Methods
brapi_post_methods( con = NULL, additionalInfo = list(), bibliographicalReference = "", description = "", externalReferences = "", formula = "", methodClass = "", methodName = "", ontologyReference = list() )
con |
list; required: TRUE; BrAPI connection object |
additionalInfo |
list; required: FALSE; Additional arbitrary information. If provided use the following construct list(additionalProp1 = "string", additionalProp2 = "string", additionalProp3 = "string"). The Examples section shows an example on how to construct the
|
bibliographicalReference |
character; required: FALSE; Bibliographical reference describing the method. MIAPPE V1.1 (DM-91) Reference associated to the method - URI/DOI of reference describing the method. |
description |
character; required: FALSE; Method description. MIAPPE V1.1 (DM-90) Method description - Textual description of the method, which may extend a method defined in an external reference with specific parameters, e.g. growth stage, inoculation precise organ (leaf number). |
externalReferences |
data.frame; required: FALSE; A data.frame of
external reference ids. These are references to this piece of data in an
external system. Could be a simple string or a URI. The
The Examples section shows an example of how to construct the
|
formula |
character; required: FALSE; For computational methods, i.e. when the method consists in assessing the trait by computing measurements, write the generic formula used for the calculation. |
methodClass |
character; required: FALSE; Method class (examples: "Measurement", "Counting", "Estimation", "Computation", etc.). |
methodName |
character; required: FALSE; Human readable name for the method. MIAPPE V1.1 (DM-88) Method Name of the method of observation. |
ontologyReference |
list; required: FALSE; MIAPPE V1.1 (DM-85) Variable accession number - Accession number of the variable in the Crop Ontology. (DM-87) Trait accession number - Accession number of the trait in a suitable controlled vocabulary (Crop Ontology, Trait Ontology). (DM-89) Method accession number - Accession number of the method in a suitable controlled vocabulary (Crop Ontology, Trait Ontology). (DM-93) Scale accession number - Accession number of the scale in a suitable controlled vocabulary (Crop Ontology). The
The Examples section shows an example of how to construct the
|
Create new method objects in the database
data.frame
Maikel Verouden
Other brapi-phenotyping:
brapi_get_events(),
brapi_get_images_imageDbId(),
brapi_get_images(),
brapi_get_methods_methodDbId(),
brapi_get_methods(),
brapi_get_observationlevels(),
brapi_get_observations_observationDbId(),
brapi_get_observations_table(),
brapi_get_observations(),
brapi_get_observationunits_observationUnitDbId(),
brapi_get_observationunits_table(),
brapi_get_observationunits(),
brapi_get_ontologies(),
brapi_get_scales_scaleDbId(),
brapi_get_scales(),
brapi_get_search_images_searchResultsDbId(),
brapi_get_search_observations_searchResultsDbId(),
brapi_get_search_observationunits_searchResultsDbId(),
brapi_get_search_variables_searchResultsDbId(),
brapi_get_traits_traitDbId(),
brapi_get_traits(),
brapi_get_variables_observationVariableDbId(),
brapi_get_variables(),
brapi_post_images(),
brapi_post_observations(),
brapi_post_observationunits(),
brapi_post_scales(),
brapi_post_search_images(),
brapi_post_search_observations(),
brapi_post_search_observationunits(),
brapi_post_search_variables(),
brapi_post_traits(),
brapi_post_variables(),
brapi_put_images_imageDbId_imagecontent(),
brapi_put_images_imageDbId(),
brapi_put_methods_methodDbId(),
brapi_put_observations_observationDbId(),
brapi_put_observationunits_observationUnitDbId(),
brapi_put_scales_scaleDbId(),
brapi_put_traits_traitDbId(),
brapi_put_variables_observationVariableDbId()
Other Methods:
brapi_get_methods_methodDbId(),
brapi_get_methods(),
brapi_put_methods_methodDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
additionalInfo <- list(dummyData = "TRUE",
example = "post_methods")
bibliographicalReference <- "Smith, 1893, Really Cool Paper, Popular Journal"
description <- "Discriminant for root finding of quadratic functions"
externalReferences <-
data.frame(referenceID = c("doi:10.155454/12341234",
"http://purl.obolibrary.org/obo/ro.owl",
"75a50e76"),
referenceSource = c("DOI",
"OBO Library",
"Remote Data Collection Upload Tool"))
formula <- "b^2 - 4ac"
methodClass <- "Computation"
methodName <- "Discriminant"
ontologyReference <- list(
documentationLinks = data.frame(
URL = c("http://purl.obolibrary.org/obo/ro.owl",
"https://en.wikipedia.org/wiki/Discriminant"),
type = c("OBO",
"WEBPAGE")),
ontologyDbId = "ontology_attribute1",
ontologyName = "Ontology.org",
version = "17")
## Add the new method
brapi_post_methods(con = con,
additionalInfo = additionalInfo,
bibliographicalReference = bibliographicalReference,
description = description,
externalReferences = externalReferences,
formula = formula,
methodClass = methodClass,
methodName = methodName,
ontologyReference = ontologyReference)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.