View source: R/brapi_post_people.R
| brapi_post_people | R Documentation |
Create new People
brapi_post_people( con = NULL, additionalInfo = list(), description = "", emailAddress = "", externalReferences = "", firstName = "", middleName = "", lastName = "", mailingAddress = "", phoneNumber = "", userID = "" )
con |
list; required: TRUE; BrAPI connection object |
additionalInfo |
list; required: FALSE; Additional arbitrary information. If provided use the following construct list(additionalProp1 = "string", additionalProp2 = "string", additionalProp3 = "string"). The Examples section shows an example on how to construct the
|
description |
character; required: FALSE; A description of this person. |
emailAddress |
character; required: FALSE; An email address for this person. |
externalReferences |
data.frame; required: FALSE; A data.frame of
external reference ids. These are references to this piece of data in an
external system. Could be a simple string or a URI. The
The Examples section shows an example of how to construct the
|
firstName |
character; required: FALSE; Persons first name. |
middleName |
character; required: FALSE; Persons middle name. |
lastName |
character; required: FALSE; Persons last name. |
mailingAddress |
character; required: FALSE; Physical address of this person. |
phoneNumber |
character; required: FALSE; phone number of this person. |
userID |
character; required: FALSE; A systems user ID associated with
this person. Different from |
Create new People entities. personDbId is generated and managed by the server.
data.frame
Maikel Verouden
Other brapi-core:
brapi_get_commoncropnames(),
brapi_get_lists_listDbId(),
brapi_get_lists(),
brapi_get_locations_locationDbId(),
brapi_get_locations(),
brapi_get_people_personDbId(),
brapi_get_people(),
brapi_get_programs_programDbId(),
brapi_get_programs(),
brapi_get_search_lists_searchResultsDbId(),
brapi_get_search_locations_searchResultsDbId(),
brapi_get_search_people_searchResultsDbId(),
brapi_get_search_programs_searchResultsDbId(),
brapi_get_search_studies_searchResultsDbId(),
brapi_get_search_trials_searchResultsDbId(),
brapi_get_seasons_seasonDbId(),
brapi_get_seasons(),
brapi_get_serverinfo(),
brapi_get_studies_studyDbId(),
brapi_get_studies(),
brapi_get_studytypes(),
brapi_get_trials_trialDbId(),
brapi_get_trials(),
brapi_post_lists_listDbId_items(),
brapi_post_lists(),
brapi_post_locations(),
brapi_post_programs(),
brapi_post_search_lists(),
brapi_post_search_locations(),
brapi_post_search_people(),
brapi_post_search_programs(),
brapi_post_search_studies(),
brapi_post_search_trials(),
brapi_post_seasons(),
brapi_post_studies(),
brapi_post_trials(),
brapi_put_lists_listDbId(),
brapi_put_locations_locationDbId(),
brapi_put_people_personDbId(),
brapi_put_programs_programDbId(),
brapi_put_seasons_seasonDbId(),
brapi_put_studies_studyDbId(),
brapi_put_trials_trialDbId()
Other People:
brapi_get_people_personDbId(),
brapi_get_people(),
brapi_get_search_people_searchResultsDbId(),
brapi_post_search_people(),
brapi_put_people_personDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
additionalInfo <- list(additionalProp1 = "string",
additionalProp2 = "string",
additionalProp3 = "string")
description <- "Bob likes pina coladas and getting caught in the rain."
emailAddress <- "bob@bob.com"
externalReferences <-
data.frame(referenceID = c("doi:10.155454/12341234",
"http://purl.obolibrary.org/obo/ro.owl",
"75a50e76"),
referenceSource = c("DOI",
"OBO Library",
"Remote Data Collection Upload Tool"))
firstName <- "Bob"
middleName <- "Danger"
lastName <- "Robertson"
mailingAddress <- "123 Street Ave, City, State, Country"
phoneNumber <- "+1-555-555-5555"
userID <- "bob-23"
brapi_post_people(con = con,
additionalInfo = additionalInfo,
description = description,
emailAddress = emailAddress,
externalReferences = externalReferences,
firstName = firstName,
middleName = middleName,
lastName = lastName,
mailingAddress = mailingAddress,
phoneNumber = phoneNumber,
userID = userID)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.