View source: R/brapi_post_programs.R
| brapi_post_programs | R Documentation |
Add new breeding Programs to the database
brapi_post_programs( con = NULL, abbreviation = "", additionalInfo = list(), commonCropName = "", documentationURL = "", externalReferences = "", leadPersonDbId = "", leadPersonName = "", objective = "", programName = "" )
con |
list; required: TRUE; BrAPI connection object |
abbreviation |
character; required: FALSE; An abbreviation which represents this program. |
additionalInfo |
list; required: FALSE; Additional arbitrary information. If provided use the following construct list(additionalProp1 = "string", additionalProp2 = "string", additionalProp3 = "string"). The Examples section shows an example on how to construct the
|
commonCropName |
character; required: FALSE; Common name for the crop, which this program is for. |
documentationURL |
character; required: FALSE; A URL to the human readable documentation of this object. |
externalReferences |
data.frame; required: FALSE; A data.frame of
external reference ids. These are references to this piece of data in an
external system. Could be a simple string or a URI. The
The Examples section shows an example of how to construct the
|
leadPersonDbId |
character; required: FALSE; The unique identifier of
the program leader. Needs to be an existing |
leadPersonName |
character; required: FALSE; The name of the program leader. |
objective |
character; required: FALSE; The primary objective of the program. |
programName |
character; required: FALSE; Human readable name of the program. |
Add new breeding Programs to the database. The programDbId is set
by the server, all other fields are take from the request body,
or a default value is used.
data.frame
Maikel Verouden
Other brapi-core:
brapi_get_commoncropnames(),
brapi_get_lists_listDbId(),
brapi_get_lists(),
brapi_get_locations_locationDbId(),
brapi_get_locations(),
brapi_get_people_personDbId(),
brapi_get_people(),
brapi_get_programs_programDbId(),
brapi_get_programs(),
brapi_get_search_lists_searchResultsDbId(),
brapi_get_search_locations_searchResultsDbId(),
brapi_get_search_people_searchResultsDbId(),
brapi_get_search_programs_searchResultsDbId(),
brapi_get_search_studies_searchResultsDbId(),
brapi_get_search_trials_searchResultsDbId(),
brapi_get_seasons_seasonDbId(),
brapi_get_seasons(),
brapi_get_serverinfo(),
brapi_get_studies_studyDbId(),
brapi_get_studies(),
brapi_get_studytypes(),
brapi_get_trials_trialDbId(),
brapi_get_trials(),
brapi_post_lists_listDbId_items(),
brapi_post_lists(),
brapi_post_locations(),
brapi_post_people(),
brapi_post_search_lists(),
brapi_post_search_locations(),
brapi_post_search_people(),
brapi_post_search_programs(),
brapi_post_search_studies(),
brapi_post_search_trials(),
brapi_post_seasons(),
brapi_post_studies(),
brapi_post_trials(),
brapi_put_lists_listDbId(),
brapi_put_locations_locationDbId(),
brapi_put_people_personDbId(),
brapi_put_programs_programDbId(),
brapi_put_seasons_seasonDbId(),
brapi_put_studies_studyDbId(),
brapi_put_trials_trialDbId()
Other Programs:
brapi_get_programs_programDbId(),
brapi_get_programs(),
brapi_get_search_programs_searchResultsDbId(),
brapi_post_search_programs(),
brapi_put_programs_programDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
abbreviation <- "P1"
additionalInfo <- list(additionalProp1 = "string",
additionalProp2 = "string",
additionalProp3 = "string")
commonCropName <- "Tomatillo"
documentationURL <- "https://wiki.brapi.org"
externalReferences <-
data.frame(referenceID = c("doi:10.155454/12341234",
"http://purl.obolibrary.org/obo/ro.owl",
"75a50e76"),
referenceSource = c("DOI",
"OBO Library",
"Remote Data Collection Upload Tool"))
leadPersonDbId <- "program_person_1"
leadPersonName <- "Bob Robertson"
objective <- "Make a better tomatillo"
programName <- "Tomatillo_Breeding_Program"
brapi_post_programs(con = con,
abbreviation = abbreviation,
additionalInfo = additionalInfo,
commonCropName = commonCropName,
documentationURL = documentationURL,
externalReferences = externalReferences,
leadPersonDbId = leadPersonDbId,
leadPersonName = leadPersonName,
objective = objective,
programName = programName)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.