View source: R/brapi_post_scales.R
| brapi_post_scales | R Documentation |
Add new Scales
brapi_post_scales( con = NULL, additionalInfo = list(), dataType = "", decimalPlaces = 0, externalReferences = "", ontologyReference = list(), scaleName = "", validValues = list() )
con |
list; required: TRUE; BrAPI connection object |
additionalInfo |
list; required: FALSE; Additional arbitrary information. If provided use the following construct list(additionalProp1 = "string", additionalProp2 = "string", additionalProp3 = "string"). The Examples section shows an example on how to construct the
|
dataType |
character; required: FALSE; Class of the scale, entries can be:
|
decimalPlaces |
integer; required: FALSE; For numerical, number of decimal places to be reported. |
externalReferences |
data.frame; required: FALSE; A data.frame of
external reference ids. These are references to this piece of data in an
external system. Could be a simple string or a URI. The
The Examples section shows an example of how to construct the
|
ontologyReference |
list; required: FALSE; MIAPPE V1.1 (DM-85) Variable accession number - Accession number of the variable in the Crop Ontology. (DM-87) Trait accession number - Accession number of the trait in a suitable controlled vocabulary (Crop Ontology, Trait Ontology). (DM-89) Method accession number - Accession number of the method in a suitable controlled vocabulary (Crop Ontology, Trait Ontology). (DM-93) Scale accession number - Accession number of the scale in a suitable controlled vocabulary (Crop Ontology). The
The Examples section shows an example of how to construct the
|
scaleName |
character; required: FALSE; Name of the scale. MIAPPE V1.1 (DM-92) Scale Name of the scale associated with the variable. |
validValues |
list; required: FALSE; Valid values for the scale. The
The Examples section shows an example of how to construct the
|
Create new scale objects in the database
data.frame
Maikel Verouden
Other brapi-phenotyping:
brapi_get_events(),
brapi_get_images_imageDbId(),
brapi_get_images(),
brapi_get_methods_methodDbId(),
brapi_get_methods(),
brapi_get_observationlevels(),
brapi_get_observations_observationDbId(),
brapi_get_observations_table(),
brapi_get_observations(),
brapi_get_observationunits_observationUnitDbId(),
brapi_get_observationunits_table(),
brapi_get_observationunits(),
brapi_get_ontologies(),
brapi_get_scales_scaleDbId(),
brapi_get_scales(),
brapi_get_search_images_searchResultsDbId(),
brapi_get_search_observations_searchResultsDbId(),
brapi_get_search_observationunits_searchResultsDbId(),
brapi_get_search_variables_searchResultsDbId(),
brapi_get_traits_traitDbId(),
brapi_get_traits(),
brapi_get_variables_observationVariableDbId(),
brapi_get_variables(),
brapi_post_images(),
brapi_post_methods(),
brapi_post_observations(),
brapi_post_observationunits(),
brapi_post_search_images(),
brapi_post_search_observations(),
brapi_post_search_observationunits(),
brapi_post_search_variables(),
brapi_post_traits(),
brapi_post_variables(),
brapi_put_images_imageDbId_imagecontent(),
brapi_put_images_imageDbId(),
brapi_put_methods_methodDbId(),
brapi_put_observations_observationDbId(),
brapi_put_observationunits_observationUnitDbId(),
brapi_put_scales_scaleDbId(),
brapi_put_traits_traitDbId(),
brapi_put_variables_observationVariableDbId()
Other Scales:
brapi_get_scales_scaleDbId(),
brapi_get_scales(),
brapi_put_scales_scaleDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
## Create function argument values
additionalInfo <- list(dummyData = "TRUE",
example = "post_scales")
dataType <- "Numerical"
decimalPlaces <- 2
externalReferences <-
data.frame(referenceID = c("doi:10.155454/12341234",
"http://purl.obolibrary.org/obo/ro.owl",
"75a50e76"),
referenceSource = c("DOI",
"OBO Library",
"Remote Data Collection Upload Tool"))
ontologyReference <- list(
documentationLinks = data.frame(
URL = c("http://purl.obolibrary.org/obo/ro.owl",
"https://en.wikipedia.org/wiki/Scale"),
type = c("OBO",
"WEBPAGE")),
ontologyDbId = "ontology_attribute1",
ontologyName = "Ontology.org",
version = "17")
scaleName <- "Meters"
validValues <- list(
categories = data.frame(
label = c("low", "medium", "high"),
value = c("0", "5", "10")),
max = 9999,
min = 2)
## Add the new scale
brapi_post_scales(con = con,
additionalInfo = additionalInfo,
dataType = dataType,
decimalPlaces = decimalPlaces,
externalReferences = externalReferences,
ontologyReference = ontologyReference,
scaleName = scaleName,
validValues = validValues)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.