View source: R/brapi_post_search_calls.R
| brapi_post_search_calls | R Documentation |
Submit a search request for Calls
brapi_post_search_calls( con = NULL, callSetDbIds = "", expandHomozygotes = NA, pageSize = 1000, pageToken = "", sepPhased = "", sepUnphased = "", unknownString = "", variantDbIds = "", variantSetDbIds = "" )
con |
list; required: TRUE; BrAPI connection object |
callSetDbIds |
vector of type character; required: FALSE; The CallSet to search for specified as unique database callset identifier(s).; default: "", when using multiple values supply as c("value1", "value2"). |
expandHomozygotes |
logical; required: FALSE; Should homozygotes be expanded (TRUE) or collapsed into a single occurrence (FALSE); default: NA , other possible values: TRUE | FALSE. |
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
pageToken |
character; required: FALSE; Used to request a specific page
of data to be returned. Tokenized pages are for large data sets, which can
not be efficiently broken into indexed pages. Use the |
sepPhased |
character; required: FALSE; The string to use as a separator for phased allele calls. |
sepUnphased |
character; required: FALSE; The string to use as a separator for unphased allele calls. |
unknownString |
character; required: FALSE; The string used as a representation for missing data.; default: "". |
variantDbIds |
vector of type character; required: FALSE; The unique variant database identifier(s) to search for.; default: "", when using multiple values supply as c("value1", "value2"). |
variantSetDbIds |
vector of type character; required: FALSE; The unique variantset database identifier(s) to search for.; default: "", when using multiple values supply as c("value1", "value2"). |
Submit a search request for Calls. Function will return either the
search results (Status 200 for an immediate response) or a
searchResultsDbId (Status 202 for both a saved and an asynchronous
search).
data.frame
Maikel Verouden
Other brapi-genotyping:
brapi_get_callsets_callSetDbId_calls(),
brapi_get_callsets_callSetDbId(),
brapi_get_callsets(),
brapi_get_calls(),
brapi_get_maps_mapDbId_linkagegroups(),
brapi_get_maps_mapDbId(),
brapi_get_maps(),
brapi_get_markerpositions(),
brapi_get_references_referenceDbId_bases(),
brapi_get_references_referenceDbId(),
brapi_get_referencesets_referenceSetDbId(),
brapi_get_referencesets(),
brapi_get_references(),
brapi_get_samples_sampleDbId(),
brapi_get_samples(),
brapi_get_search_calls_searchResultsDbId(),
brapi_get_search_callsets_searchResultsDbId(),
brapi_get_search_markerpositions_searchResultsDbId(),
brapi_get_search_references_searchResultsDbId(),
brapi_get_search_referencesets_searchResultsDbId(),
brapi_get_search_samples_searchResultsDbId(),
brapi_get_search_variants_searchResultsDbId(),
brapi_get_search_variantsets_searchResultsDbId(),
brapi_get_variants_variantDbId_calls(),
brapi_get_variants_variantDbId(),
brapi_get_variantsets_variantSetDbId_callsets(),
brapi_get_variantsets_variantSetDbId_calls(),
brapi_get_variantsets_variantSetDbId_variants(),
brapi_get_variantsets_variantSetDbId(),
brapi_get_variantsets(),
brapi_get_variants(),
brapi_get_vendor_orders_orderId_plates(),
brapi_get_vendor_orders_orderId_results(),
brapi_get_vendor_orders_orderId_status(),
brapi_get_vendor_orders(),
brapi_get_vendor_specifications(),
brapi_post_samples(),
brapi_post_search_callsets(),
brapi_post_search_markerpositions(),
brapi_post_search_referencesets(),
brapi_post_search_references(),
brapi_post_search_samples(),
brapi_post_search_variantsets(),
brapi_post_search_variants(),
brapi_post_variantsets_extract(),
brapi_put_samples_sampleDbId()
Other Calls:
brapi_get_calls(),
brapi_get_search_calls_searchResultsDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
# Immediate Response Example
brapi_post_search_calls(con = con, pageSize = 1000)
# Saved or Asynchronous Search Response Example
brapi_post_search_calls(con = con,
callSetDbIds = c("callset12",
"callset21"),
expandHomozygotes = TRUE,
pageSize = 1000,
sepPhased = "/",
sepUnphased = "|",
unknownString = "-",
variantDbIds = c("variant01",
"variant23"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.