View source: R/brapi_post_search_callsets.R
| brapi_post_search_callsets | R Documentation |
Submit a search request for CallSets
brapi_post_search_callsets( con = NULL, callSetDbIds = "", callSetNames = "", germplasmDbIds = "", germplasmNames = "", page = 0, pageSize = 1000, sampleDbIds = "", sampleNames = "", variantSetDbIds = "" )
con |
list; required: TRUE; BrAPI connection object |
callSetDbIds |
vector of type character; required: FALSE; The CallSet to search for specified as unique database callset identifier(s).; default: "", when using multiple values supply as c("value1", "value2"). |
callSetNames |
vector of type character; required: FALSE; Only return call sets with these names (case-sensitive, exact match).; default: "", when using multiple values supply as c("value1", "value2"). |
germplasmDbIds |
vector of type character; required: FALSE; Vector of database identifiers which uniquely identify germplasm to search for; default: "", when using multiple values supply as c("value1", "value2"). |
germplasmNames |
vector of type character; required: FALSE; List of human readable names to identify germplasm to search for; default: "", when using multiple values supply as c("value1", "value2"). |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is
|
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
sampleDbIds |
vector of type character; required: FALSE; Return only call sets generated from the provided unique database Biosample identifiers; default: "", when using multiple values supply as c("value1", "value2"). |
sampleNames |
vector of type character; required: FALSE; Return only call sets generated from the provided Biosample human readable names.; default: "", when using multiple values supply as c("value1", "value2"). |
variantSetDbIds |
vector of type character; required: FALSE; The unique VariantSet database identifier(s) to search for; default: "", when using multiple values supply as c("value1", "value2"). |
Submit a search request for CallSets. Function will return either
the search results (Status 200 for an immediate response) or a
searchResultsDbId (Status 202 for both a saved and an asynchronous
search).
data.frame
Maikel Verouden
Other brapi-genotyping:
brapi_get_callsets_callSetDbId_calls(),
brapi_get_callsets_callSetDbId(),
brapi_get_callsets(),
brapi_get_calls(),
brapi_get_maps_mapDbId_linkagegroups(),
brapi_get_maps_mapDbId(),
brapi_get_maps(),
brapi_get_markerpositions(),
brapi_get_references_referenceDbId_bases(),
brapi_get_references_referenceDbId(),
brapi_get_referencesets_referenceSetDbId(),
brapi_get_referencesets(),
brapi_get_references(),
brapi_get_samples_sampleDbId(),
brapi_get_samples(),
brapi_get_search_calls_searchResultsDbId(),
brapi_get_search_callsets_searchResultsDbId(),
brapi_get_search_markerpositions_searchResultsDbId(),
brapi_get_search_references_searchResultsDbId(),
brapi_get_search_referencesets_searchResultsDbId(),
brapi_get_search_samples_searchResultsDbId(),
brapi_get_search_variants_searchResultsDbId(),
brapi_get_search_variantsets_searchResultsDbId(),
brapi_get_variants_variantDbId_calls(),
brapi_get_variants_variantDbId(),
brapi_get_variantsets_variantSetDbId_callsets(),
brapi_get_variantsets_variantSetDbId_calls(),
brapi_get_variantsets_variantSetDbId_variants(),
brapi_get_variantsets_variantSetDbId(),
brapi_get_variantsets(),
brapi_get_variants(),
brapi_get_vendor_orders_orderId_plates(),
brapi_get_vendor_orders_orderId_results(),
brapi_get_vendor_orders_orderId_status(),
brapi_get_vendor_orders(),
brapi_get_vendor_specifications(),
brapi_post_samples(),
brapi_post_search_calls(),
brapi_post_search_markerpositions(),
brapi_post_search_referencesets(),
brapi_post_search_references(),
brapi_post_search_samples(),
brapi_post_search_variantsets(),
brapi_post_search_variants(),
brapi_post_variantsets_extract(),
brapi_put_samples_sampleDbId()
Other Call Sets:
brapi_get_callsets_callSetDbId_calls(),
brapi_get_callsets_callSetDbId(),
brapi_get_callsets(),
brapi_get_search_callsets_searchResultsDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
# Immediate Response Example
brapi_post_search_callsets(con = con,
page = 0,
pageSize = 1000)
# Saved or Asynchronous Search Response Example
brapi_post_search_callsets(con = con,
callSetDbIds = c("callset01",
"callset02"),
page = 0,
pageSize = 1000,
sampleDbIds = c("sample3",
"sample2"),
variantSetDbIds = c("variantset1"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.