View source: R/brapi_post_search_germplasm.R
| brapi_post_search_germplasm | R Documentation |
Submit a search request for Germplasm
brapi_post_search_germplasm( con = NULL, accessionNumbers = "", collections = "", commonCropNames = "", externalReferenceIDs = "", externalReferenceSources = "", genus = "", germplasmDbIds = "", germplasmNames = "", germplasmPUIs = "", parentDbIds = "", progenyDbIds = "", species = "", studyDbIds = "", studyNames = "", synonyms = "", page = 0, pageSize = 1000 )
con |
list; required: TRUE; BrAPI connection object |
accessionNumbers |
vector of type character; required: FALSE; The unique identifiers for accessions within a genebank; default: "", when using multiple values supply as c("value1", "value2"). |
collections |
vector of type character; required: FALSE; A specific panel/collection/population name this germplasm belongs to.; default: "", when using multiple values supply as c("value1", "value2"). |
commonCropNames |
vector of type character; required: FALSE; Common name for the crop which this program is for; default: "", when using multiple values supply as c("value1", "value2"). |
externalReferenceIDs |
vector of type character; required: FALSE; The
external reference IDs to search for. Could be a simple strings or a URIs.
(use with |
externalReferenceSources |
vector of type character; required: FALSE;
The identifiers for the source system or database of an external reference
to search for (use with |
genus |
vector of type character; required: FALSE; The Genus names to identify germplasm to search for; default: "", when using multiple values supply as c("value1", "value2"). |
germplasmDbIds |
vector of type character; required: FALSE; The unique germplasm database idetifier(s) to search for; default: "", when using multiple values supply as c("value1", "value2"). |
germplasmNames |
vector of type character; required: FALSE; The human readable names to identify germplasm to search for; default: "", when using multiple values supply as c("value1", "value2"). |
germplasmPUIs |
vector of type character; required: FALSE; The Permanent Unique Identifiers to identify germplasm to search for; default: "", when using multiple values supply as c("value1", "value2"). |
parentDbIds |
vector of type character; required: FALSE; Search for Germplasm with these unique parents database identifier(s); default: "", when using multiple values supply as c("value1", "value2"). |
progenyDbIds |
vector of type character; required: FALSE; Search for Germplasm with these unique children database identifier(s); default: "", when using multiple values supply as c("value1", "value2"). |
species |
vector of type character; required: FALSE; The species names to identify germplasm to search for; default: "", when using multiple values supply as c("value1", "value2"). |
studyDbIds |
vector of type character; required: FALSE; The unique study database identifier(s) to search for; default: "", when using multiple values supply as c("value1", "value2"). |
studyNames |
vector of type character; required: FALSE; The study names to filter search results; default: "", when using multiple values supply as c("value1", "value2"). |
synonyms |
vector of type character; required: FALSE; The alternative names or IDs used to reference this germplasm; default: "", when using multiple values supply as c("value1", "value2"). |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is
|
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
Submit a search request for Germplasm. Function will return either
the search results (Status 200 for an immediate response) or a
searchResultsDbId (Status 202 for both a saved and an asynchronous
search).
data.frame
Maikel Verouden
Other brapi-germplasm:
brapi_get_attributes(),
brapi_get_attributevalues(),
brapi_get_germplasm(),
brapi_get_search_attributes_searchResultsDbId(),
brapi_get_search_attributevalues_searchResultsDbId(),
brapi_get_search_germplasm_searchResultsDbId(),
brapi_post_search_attributes(),
brapi_post_search_attributevalues()
Other Germplasm:
brapi_get_germplasm(),
brapi_get_search_germplasm_searchResultsDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
# Immediate Response Example
brapi_post_search_germplasm(con = con, page = 0, pageSize = 1000)
# Saved or Asynchronous Search Response Example
brapi_post_search_germplasm(con = con,
accessionNumbers = c("A0000001",
"A0000003"),
collections = "Fake Foods Collection",
commonCropNames = "Tomatillo",
genus = "Aspergillus",
germplasmDbIds = c("germplasm1",
"germplasm3"),
page = 0,
pageSize = 1000)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.