View source: R/brapi_post_search_referencesets.R
| brapi_post_search_referencesets | R Documentation |
Submit a search request for ReferenceSets
brapi_post_search_referencesets( con = NULL, referenceSetDbIds = "", accessions = "", assemblyPUIs = "", md5checksums = "", page = 0, pageSize = 1000 )
con |
list; required: TRUE; BrAPI connection object |
referenceSetDbIds |
vector of type character; required: FALSE; The unique database identifier(s) of a reference set or reference sets to search.; default: "", when using multiple values supply as c( "value1", "value2"). |
accessions |
vector of type character; required: FALSE; If specified, return the reference sets for which the accession matches this string (case-sensitive, exact match); default: "", when using multiple values supply as c("value1", "value2"). |
assemblyPUIs |
vector of type character; required: FALSE; If set, return
the reference sets for which the |
md5checksums |
vector of type character; required: FALSE; If specified,
return the reference sets for which the |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is
|
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
Submit a search request for ReferenceSets. Function will return
either the search results (Status 200 for an immediate response) or a
searchResultsDbId (Status 202 for both a saved and an asynchronous
search).
data.frame
Maikel Verouden
Other brapi-genotyping:
brapi_get_callsets_callSetDbId_calls(),
brapi_get_callsets_callSetDbId(),
brapi_get_callsets(),
brapi_get_calls(),
brapi_get_maps_mapDbId_linkagegroups(),
brapi_get_maps_mapDbId(),
brapi_get_maps(),
brapi_get_markerpositions(),
brapi_get_references_referenceDbId_bases(),
brapi_get_references_referenceDbId(),
brapi_get_referencesets_referenceSetDbId(),
brapi_get_referencesets(),
brapi_get_references(),
brapi_get_samples_sampleDbId(),
brapi_get_samples(),
brapi_get_search_calls_searchResultsDbId(),
brapi_get_search_callsets_searchResultsDbId(),
brapi_get_search_markerpositions_searchResultsDbId(),
brapi_get_search_references_searchResultsDbId(),
brapi_get_search_referencesets_searchResultsDbId(),
brapi_get_search_samples_searchResultsDbId(),
brapi_get_search_variants_searchResultsDbId(),
brapi_get_search_variantsets_searchResultsDbId(),
brapi_get_variants_variantDbId_calls(),
brapi_get_variants_variantDbId(),
brapi_get_variantsets_variantSetDbId_callsets(),
brapi_get_variantsets_variantSetDbId_calls(),
brapi_get_variantsets_variantSetDbId_variants(),
brapi_get_variantsets_variantSetDbId(),
brapi_get_variantsets(),
brapi_get_variants(),
brapi_get_vendor_orders_orderId_plates(),
brapi_get_vendor_orders_orderId_results(),
brapi_get_vendor_orders_orderId_status(),
brapi_get_vendor_orders(),
brapi_get_vendor_specifications(),
brapi_post_samples(),
brapi_post_search_callsets(),
brapi_post_search_calls(),
brapi_post_search_markerpositions(),
brapi_post_search_references(),
brapi_post_search_samples(),
brapi_post_search_variantsets(),
brapi_post_search_variants(),
brapi_post_variantsets_extract(),
brapi_put_samples_sampleDbId()
Other Reference Sets:
brapi_get_referencesets_referenceSetDbId(),
brapi_get_referencesets(),
brapi_get_search_referencesets_searchResultsDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
# Immediate Response Example
brapi_post_search_referencesets(con = con,
page = 0,
pageSize = 1000)
# Saved or Asynchronous Search Response Example
brapi_post_search_referencesets(
con = con,
referenceSetDbIds = c("reference_set1",
"reference_set2"),
accessions = c("A0000001",
"A0000002"),
assemblyPUIs = "doi://10.12345/fake/9876",
md5checksums = "0ba836092b9efada3a4aa72bb0eb0e04",
page = 0,
pageSize = 1000)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.