View source: R/brapi_post_search_variables.R
| brapi_post_search_variables | R Documentation |
Submit a search request for Observation Variables
brapi_post_search_variables( con = NULL, dataTypes = "", externalReferenceIDs = "", externalReferenceSources = "", methodDbIds = "", observationVariableDbIds = "", observationVariableNames = "", ontologyDbIds = "", page = 0, pageSize = 1000, scaleDbIds = "", studyDbId = "", traitClasses = "", traitDbIds = "" )
con |
list; required: TRUE; BrAPI connection object |
dataTypes |
vector of type character; required: FALSE; List of scale data types to filter search results. Class of the scale entries can be:
default: "", when using multiple values supply as c( "value1", "value2"). |
externalReferenceIDs |
vector of type character; required: FALSE; List
of external reference IDs. Could be a simple strings or a URIs. (use with
|
externalReferenceSources |
vector of type character; required: FALSE;
List of identifiers for the source system or database of an external
reference (use with |
methodDbIds |
vector of type character; required: FALSE; List of methods , supplied as unique database identifiers, to filter search results; default: "", when using multiple values supply as c( "value1", "value2"). |
observationVariableDbIds |
vector of type character; required: FALSE; List of unique observation variable datbase identifiers to search for; default: "", when using multiple values supply as c( "value1", "value2"). |
observationVariableNames |
vector of type character; required: FALSE; List of human readable observation variable names to search for; default: "", when using multiple values supply as c("value1", "value2"). |
ontologyDbIds |
vector of type character; required: FALSE; List of unique ontology database identifiers to search for; default: "", when using multiple values supply as c("value1", "value2"). |
page |
integer; required: FALSE; Used to request a specific page of data
to be returned. The page indexing starts at 0 (the first page is
|
pageSize |
integer; required: FALSE; The size of the pages to be
returned. Default is |
scaleDbIds |
vector of type character; required: FALSE; List of unique scale database identifiers to filter search results; default: "" , when using multiple values supply as c("value1", "value2"). |
studyDbId |
vector of type character; required: FALSE; The unique database identifiers of studies to filter on; default: "", when using multiple values supply as c("value1", "value2"). |
traitClasses |
vector of type character; required: FALSE; List of trait classes to filter search results, examples: "morphological", "phenological", "agronomical", "physiological", "abiotic stress", "biotic stress", "biochemical", "quality traits", "fertility", etc.); default: "", when using multiple values supply as c("value1", "value2"). |
traitDbIds |
vector of type character; required: FALSE; List of trait unique database identifiers to filter search results; default: "", when using multiple values supply as c("value1", "value2"). |
Submit a search request for Observation Variables. Function will
return either the search results (Status 200 for an immediate response) or
a searchResultsDbId (Status 202 for both a saved and an asynchronous
search).
data.frame
Maikel Verouden
Other brapi-phenotyping:
brapi_get_events(),
brapi_get_images_imageDbId(),
brapi_get_images(),
brapi_get_methods_methodDbId(),
brapi_get_methods(),
brapi_get_observationlevels(),
brapi_get_observations_observationDbId(),
brapi_get_observations_table(),
brapi_get_observations(),
brapi_get_observationunits_observationUnitDbId(),
brapi_get_observationunits_table(),
brapi_get_observationunits(),
brapi_get_ontologies(),
brapi_get_scales_scaleDbId(),
brapi_get_scales(),
brapi_get_search_images_searchResultsDbId(),
brapi_get_search_observations_searchResultsDbId(),
brapi_get_search_observationunits_searchResultsDbId(),
brapi_get_search_variables_searchResultsDbId(),
brapi_get_traits_traitDbId(),
brapi_get_traits(),
brapi_get_variables_observationVariableDbId(),
brapi_get_variables(),
brapi_post_images(),
brapi_post_methods(),
brapi_post_observations(),
brapi_post_observationunits(),
brapi_post_scales(),
brapi_post_search_images(),
brapi_post_search_observations(),
brapi_post_search_observationunits(),
brapi_post_traits(),
brapi_post_variables(),
brapi_put_images_imageDbId_imagecontent(),
brapi_put_images_imageDbId(),
brapi_put_methods_methodDbId(),
brapi_put_observations_observationDbId(),
brapi_put_observationunits_observationUnitDbId(),
brapi_put_scales_scaleDbId(),
brapi_put_traits_traitDbId(),
brapi_put_variables_observationVariableDbId()
Other Observation Variables:
brapi_get_search_variables_searchResultsDbId(),
brapi_get_variables_observationVariableDbId(),
brapi_get_variables(),
brapi_post_variables(),
brapi_put_variables_observationVariableDbId()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
# Immediate Response Example
brapi_post_search_variables(con = con, page = 0, pageSize = 1000)
# Saved or Asynchronous Search Response Example
brapi_post_search_variables(
con = con,
dataTypes = c("Numerical", "Text"),
externalReferenceIDs = "https://brapi.org/specification",
externalReferenceSources = "BrAPI Doc",
ontologyDbIds = "ontology_variable1",
page = 0,
pageSize = 1000)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.