View source: R/brapi_put_traits_traitDbId.R
| brapi_put_traits_traitDbId | R Documentation |
Update an existing Trait
brapi_put_traits_traitDbId( con = NULL, traitDbId = "", additionalInfo = list(), alternativeAbbreviations = "", attribute = "", entity = "", externalReferences = "", mainAbbreviation = "", ontologyReference = list(), status = "", synonyms = "", traitClass = "", traitDescription = "", traitName = "" )
con |
list; required: TRUE; BrAPI connection object |
traitDbId |
character; required: TRUE; Identifier for the trait to update details of. |
additionalInfo |
list; required: FALSE; Additional arbitrary information. If provided use the following construct list(additionalProp1 = "string", additionalProp2 = "string", additionalProp3 = "string"). The Examples section shows an example on how to construct the
|
alternativeAbbreviations |
vector of type character; required: FALSE; Other frequent abbreviations of the trait, if any. These abbreviations do not have to follow a convention; default: "", when using multiple values supply as c("value1", "value2"). |
attribute |
character; required: FALSE; A trait can be decomposed as "Trait" = "Entity" + "Attribute", the attribute is the observed feature (or characteristic) of the entity, e.g. for "grain colour", attribute = "colour". |
entity |
character; required: FALSE; A trait can be decomposed as "Trait" = "Entity" + "Attribute", the entity is the part of the plant that the trait refers to, e.g. for "grain colour", entity = "grain". |
externalReferences |
data.frame; required: FALSE; A data.frame of
external reference ids. These are references to this piece of data in an
external system. Could be a simple string or a URI. The
The Examples section shows an example of how to construct the
|
mainAbbreviation |
character; required: FALSE; Main abbreviation for trait name, examples: "Carotenoid content" => "CC"). |
ontologyReference |
list; required: FALSE; MIAPPE V1.1 (DM-85) Variable accession number - Accession number of the variable in the Crop Ontology. (DM-87) Trait accession number - Accession number of the trait in a suitable controlled vocabulary (Crop Ontology, Trait Ontology). (DM-89) Method accession number - Accession number of the method in a suitable controlled vocabulary (Crop Ontology, Trait Ontology). (DM-93) Scale accession number - Accession number of the scale in a suitable controlled vocabulary (Crop Ontology). The
The Examples section shows an example of how to construct the
|
status |
character; required: FALSE; Trait status (examples: "recommended", "obsolete", "legacy", etc.). |
synonyms |
vector of type character; required: FALSE; Other trait names; default: "", when using multiple values supply as c( "value1", "value2"). |
traitClass |
character; required: FALSE; Trait class, examples: "morphological", "phenological", "agronomical", "physiological", "abiotic stress", "biotic stress", "biochemical", "quality traits", "fertility", etc.). |
traitDescription |
character; required: FALSE; The description of a trait. |
traitName |
character; required: FALSE; The human readable name of a trait. MIAPPE V1.1 (DM-86) Trait - Name of the (plant or environmental) trait under observation. |
Update an existing trait
data.frame
Maikel Verouden
Other brapi-phenotyping:
brapi_get_events(),
brapi_get_images_imageDbId(),
brapi_get_images(),
brapi_get_methods_methodDbId(),
brapi_get_methods(),
brapi_get_observationlevels(),
brapi_get_observations_observationDbId(),
brapi_get_observations_table(),
brapi_get_observations(),
brapi_get_observationunits_observationUnitDbId(),
brapi_get_observationunits_table(),
brapi_get_observationunits(),
brapi_get_ontologies(),
brapi_get_scales_scaleDbId(),
brapi_get_scales(),
brapi_get_search_images_searchResultsDbId(),
brapi_get_search_observations_searchResultsDbId(),
brapi_get_search_observationunits_searchResultsDbId(),
brapi_get_search_variables_searchResultsDbId(),
brapi_get_traits_traitDbId(),
brapi_get_traits(),
brapi_get_variables_observationVariableDbId(),
brapi_get_variables(),
brapi_post_images(),
brapi_post_methods(),
brapi_post_observations(),
brapi_post_observationunits(),
brapi_post_scales(),
brapi_post_search_images(),
brapi_post_search_observations(),
brapi_post_search_observationunits(),
brapi_post_search_variables(),
brapi_post_traits(),
brapi_post_variables(),
brapi_put_images_imageDbId_imagecontent(),
brapi_put_images_imageDbId(),
brapi_put_methods_methodDbId(),
brapi_put_observations_observationDbId(),
brapi_put_observationunits_observationUnitDbId(),
brapi_put_scales_scaleDbId(),
brapi_put_variables_observationVariableDbId()
Other Traits:
brapi_get_traits_traitDbId(),
brapi_get_traits(),
brapi_post_traits()
## Not run:
con <- brapi_db()$testserver
con[["token"]] <- "YYYY"
additionalInfo <- list(dummyData = "TRUE",
example = "post_traits")
alternativeAbbreviations <- c("PHght", "Hght")
attribute <- "heigth"
entity <- "plant"
externalReferences <-
data.frame(referenceID = c("doi:10.155454/12341234",
"http://purl.obolibrary.org/obo/ro.owl",
"75a50e76"),
referenceSource = c("DOI",
"OBO Library",
"Remote Data Collection Upload Tool"))
mainAbbreviation <- "PH"
ontologyReference <- list(
documentationLinks = data.frame(
URL = c("http://purl.obolibrary.org/obo/ro.owl",
"https://www.cropontology.org/terms/CO_323:0000024/"),
type = c("OBO",
"WEBPAGE")),
ontologyDbId = "ontology_variable1",
ontologyName = "Ontology.org",
version = "17")
status <- "recommended"
synonyms <- c("Height",
"Plant Height")
traitClass <- "agrinomically"
traitDescription <- "The height of plant from ground."
traitName <- "Plant heigth"
## Add the new trait
out <- brapi_post_traits(
con = con,
additionalInfo = additionalInfo,
alternativeAbbreviations = alternativeAbbreviations,
attribute = attribute,
entity = entity,
externalReferences = externalReferences,
mainAbbreviation = mainAbbreviation,
ontologyReference = ontologyReference,
status = status,
synonyms = synonyms,
traitClass = traitClass,
traitDescription = traitDescription,
traitName = traitName)
## Obtain the identifier for the new trait
traitDbId <- unique(out$traitDbId)
## Retrieve the info of the new trait
brapi_get_traits_traitDbId(con = con, traitDbId)
## Update the info of the new trait
brapi_put_traits_traitDbId(
con = con,
traitDbId = traitDbId,
attribute = "Height",
synonyms = c("Height",
"Plant Height",
"Stalk Height",
"Canopy Height"),
traitClass = "agronomical",
traitDescription = "The height of plant from ground to the top part.",
traitName = "Plant height")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.